@@ -40,7 +40,12 @@ class ConfigFile:
                 self.config = orjson.loads(f.read())
 
     def sleep(self, seconds: float, result: Any) -> Any:
-        time.sleep(seconds)
+        for _ in range(10): 
+            if not self.thread_true:
+                return result
+            
+            time.sleep(seconds / 10)
+        
         return result
 
     def update_config(self) -> None:
